import fs from "node:fs/promises";
import path from "node:path";
import process from "node:process";
import { outdent as javascript } from "outdent";
import { getExtensionConfiguration } from "./utils.js";
const createHandlerEntrypointSrc = ({ slug }) => {
    return javascript `
    import { extension } from "../../.ntli/index.js";

    extension._slug = "${slug}";

    export const handler = extension.baseHandler;
  `;
};
export const writeHandlerFunction = async (mode, { constants, netlifyConfig, }) => {
    if (constants.INTERNAL_FUNCTIONS_SRC === undefined) {
        throw new Error("The current version of the Netlify CLI is too old. Please update it using `npm -g install netlify-cli` and try again.");
    }
    // The netlify CLI:
    //
    // - In a regular repo, sets process.cwd() to the repository root and does not set PACKAGE_PATH
    // - In a monorepo, sets process.cwd() to the package directory in build mode and to the
    //   repository root in dev mode, and in both modes sets constants.PACKAGE_PATH to the package
    //   we're currently running `build` or `dev` on
    // - But, if `netlifyConfig.build.base` is set, then process.cwd() is set to that value, but
    //   constants.PACKAGE_PATH is still set.
    //
    // So, if a base is set, then we should use that to resolve the extension configuration. If a base
    // is not set, resolve extension configuration relative to the package path rather than the
    // repository root or we'll fail to resolve the correct extension configuration in monorepos.
    const packagePath = netlifyConfig.build.base ??
        path.resolve(process.cwd(), constants.PACKAGE_PATH ?? "");
    const config = await getExtensionConfiguration(packagePath);
    let outdir = constants.INTERNAL_FUNCTIONS_SRC;
    // Remember: If we're iin a monorepo, in build mode, building a package, process.cwd() is set to
    // the package directory. Netlify doesn't give us any way to figure out what the repository root
    // is, and INTERNAL_FUNCTIONS_SRC is relative...to the repository root. So we need a crystal ball
    // here to figure out where we should actually write files.
    if (mode === "build" && (constants.PACKAGE_PATH ?? "") !== "") {
        outdir = path.resolve(process.cwd().replace(constants.PACKAGE_PATH ?? "", ""), constants.INTERNAL_FUNCTIONS_SRC);
    }
    await fs.mkdir(outdir, { recursive: true });
    await fs.writeFile(path.resolve(outdir, "handler.mjs"), createHandlerEntrypointSrc({ slug: config.slug }));
};
//# sourceMappingURL=write_handler_function.js.map